@@ -21,6 +21,7 @@ from .components import (
     render_vega_routes_init,
     render_vega_health_route,
     render_vega_user_route,
+    render_shared_default_route,
     render_vega_dependencies,
     render_vega_main,
     render_vega_project_main,
@@ -81,6 +82,7 @@ __all__ = [
     "render_vega_routes_init",
     "render_vega_health_route",
     "render_vega_user_route",
+    "render_shared_default_route",
     "render_vega_dependencies",
     "render_vega_main",
     "render_vega_project_main",
